@@ -22,11 +22,11 @@ use constant {
 use common::sense;
 use 5.008;
 
-use URI::Escape qw'uri_unescape';
 use RDF::RDFa::Parser::OpenDocumentObjectModel;
+use URI::Escape qw'uri_unescape';
 
 our @EXPORT_OK = qw(HOST_ATOM HOST_DATARSS HOST_HTML4 HOST_HTML5 HOST_OPENDOCUMENT_XML HOST_OPENDOCUMENT_ZIP HOST_SVG HOST_XHTML HOST_XML RDFA_10 RDFA_11);
-our $VERSION = '1.093';
+our $VERSION = '1.095';
 our $CONFIGS = {
 	'host' => {
 		HOST_ATOM() => {
@@ -107,15 +107,16 @@ our $CONFIGS = {
 			'bookmark_name'         => undef,
 			'bookmark_start'        => undef,
 			'cite_attr'             => 0,
-			'default_profiles'      => 'tag:buzzword.org.uk,2010:rdfa:profile:rdfa10',
+			'default_profiles'      => 'http://www.w3.org/1999/xhtml/vocab',
 			'dom_parser'            => 'xml',
 			'embedded_rdfxml'       => 1,
 			'full_uris'             => 0,
 			'graph'                 => 0,
 			'graph_attr'            => 'graph',
-			'graph_type'            => 'id',
+			'graph_type'            => 'about',
 			'graph_default'         => undef,
 			'graph_default_trine'   => undef,  # not officially exposed
+			'inlist_attr'           => 0,
 			'longdesc_attr'         => 0,
 			'lwp_ua'                => undef,
 			'ns'                    => undef,
@@ -124,22 +125,25 @@ our $CONFIGS = {
 			'prefix_default'        => 'http://www.w3.org/1999/xhtml/vocab#',
 			'prefix_nocase_attr'    => 0,
 			'prefix_nocase_xmlns'   => 0,
-			'profiles'              => 0,
+			'profile_attr'          => 0,
 			'profile_pi'            => 0,
 			'role_attr'             => 0,
 			'safe_anywhere'         => 0,
 			'skolemize'             => 0,
+			'src_sets_object'       => 0,
 			'tdb_service'           => 0,
 			'use_rtnlx'             => 0,
 			'user_agent'            => undef,
 			'vocab_attr'            => 0,
 			'vocab_default'         => undef,
+			'vocab_triple'          => 0,
 			'xhtml_base'            => 0,
 			'xhtml_elements'        => 0,
 			'xhtml_lang'            => 0,
 			'xml_base'              => 2,
 			'xml_lang'              => 1,
 			'xmllit_default'        => 1,
+			'xmllit_recurse'        => 0,
 			'xmlns_attr'            => 1,
 		},
 		RDFA_11() => {
@@ -151,7 +155,7 @@ our $CONFIGS = {
 			'bookmark_name'         => undef,
 			'bookmark_start'        => undef,
 			'cite_attr'             => 0,
-			'default_profiles'      => undef,
+			'default_profiles'      => 'http://www.w3.org/profile/rdfa-1.1',
 			'dom_parser'            => 'xml',
 			'embedded_rdfxml'       => 1,
 			'full_uris'             => 1, #diff
@@ -160,6 +164,7 @@ our $CONFIGS = {
 			'graph_type'            => 'about',
 			'graph_default'         => undef,
 			'graph_default_trine'   => undef,
+			'inlist_attr'           => 1, #diff
 			'longdesc_attr'         => 0,
 			'lwp_ua'                => undef,
 			'ns'                    => undef,
@@ -168,30 +173,31 @@ our $CONFIGS = {
 			'prefix_default'        => 'http://www.w3.org/1999/xhtml/vocab#',
 			'prefix_nocase_attr'    => 1, #diff
 			'prefix_nocase_xmlns'   => 1, #diff
-			'profiles'              => 1, #diff
+			'profile_attr'          => 0,
 			'profile_pi'            => 0,
 			'role_attr'             => 0,
 			'safe_anywhere'         => 1, #diff
+			'src_sets_object'       => 1, #diff
 			'skolemize'             => 0,
 			'tdb_service'           => 0,
 			'use_rtnlx'             => 0,
 			'user_agent'            => undef,
 			'vocab_attr'            => 1, #diff
 			'vocab_default'         => undef,
+			'vocab_triple'          => 1,
 			'xhtml_base'            => 0,
 			'xhtml_elements'        => 0,
 			'xhtml_lang'            => 0,
 			'xml_base'              => 2,
 			'xml_lang'              => 1,
-			'xmllit_default'        => 0,
+			'xmllit_default'        => 0, #diff
+			'xmllit_recurse'        => 1, #diff
 			'xmlns_attr'            => 1,
 		},
 	},
 	'combination' => {
 		'xhtml+1.1' => {
-			# XHTML+RDFa 1.1 uses the XHV vocab, which differs slightly
-			# from RDFa 1.0's default vocab.
-			'default_profiles'      => 'http://www.w3.org/1999/xhtml/vocab',
+			'default_profiles'      => 'http://www.w3.org/profile/html-rdfa-1.1',
 			
 			# XHTML+RDFa 1.1 wants to use @lang, though
 			# neither XHTML's host language rules, nor
@@ -199,14 +205,10 @@ our $CONFIGS = {
 			'xhtml_lang'            => 1,
 		},
 		'html4+1.1' => {
-			# HTML+RDFa 1.1 uses the XHV vocab, which differs slightly
-			# from RDFa 1.0's default vocab.
-			'default_profiles'      => 'http://www.w3.org/1999/xhtml/vocab',
+			'default_profiles'      => 'http://www.w3.org/profile/html-rdfa-1.1',
 		},
 		'html5+1.1' => {
-			# HTML+RDFa 1.1 uses the XHV vocab, which differs slightly
-			# from RDFa 1.0's default vocab.
-			'default_profiles'      => 'http://www.w3.org/1999/xhtml/vocab',
+			'default_profiles'      => 'http://www.w3.org/profile/html-rdfa-1.1',
 		},
 	},
 };
@@ -254,6 +256,24 @@ sub new
 	return $self;
 }
 
+sub tagsoup
+{
+	my ($class) = @_;
+	my @profiles = qw[
+		http://www.w3.org/1999/xhtml/vocab
+		tag:buzzword.org.uk,2010:rdfa:profile:ietf
+		tag:buzzword.org.uk,2010:rdfa:profile:forgotten
+		];
+	return $class->new(
+		HOST_HTML5,
+		RDFA_LATEST,
+		cite_attr        => 1,
+		default_profiles => join(' ', @profiles),
+		role_attr        => 1,
+		longdesc_attr    => 1,
+		);
+}
+
 sub host_from_media_type
 {
 	my ($class, $mediatype) = @_;
@@ -492,9 +512,9 @@ are accepted (e.g. 'text/html' or 'image/svg+xml').
 
 =item * B<< RDF::RDFa::Parser::Config->HOST_HTML5 >>
 
-=item * B<< RDF::RDFa::Parser::Config->HOST_OPENDOCUMENT_XML >>
+=item * B<< RDF::RDFa::Parser::Config->HOST_OPENDOCUMENT_XML >> (Flat XML: "FODT", "FODS", etc)
 
-=item * B<< RDF::RDFa::Parser::Config->HOST_OPENDOCUMENT_ZIP >>
+=item * B<< RDF::RDFa::Parser::Config->HOST_OPENDOCUMENT_ZIP >> ("ODT", "ODS", etc)
 
 =item * B<< RDF::RDFa::Parser::Config->HOST_SVG >>
 
@@ -544,7 +564,7 @@ in brackets.
 
 =item * B<cite_attr> - support @cite [0]
 
-=item * B<default_profiles> - whitespace-separated list of profiles to load by default. [undef]
+=item * B<default_profiles> - whitespace-separated list of profiles to load by default. ['http://www.w3.org/1999/xhtml/vocab', 'http://www.w3.org/profiles/rdfa-1.1 http://www.w3.org/profiles/html-rdfa-1.1']
 
 =item * B<dom_parser> - parser to use to turn a markup string into a DOM. 'html', 'opendocument' (i.e. zipped XML) or 'xml'. ['xml']
 
@@ -580,7 +600,7 @@ in brackets.
 
 =item * B<prefix_nocase_xmlns> - ignore case-sensitivity of CURIE prefixes defined via xmlns. [0, 1]
 
-=item * B<profiles> - support RDFa profiles. [0, 1]
+=item * B<profile_attr> - support RDFa profile attribute. [0]
 
 =item * B<profile_pi> - support DataRSS-style profile processing instruction. [0]
 
@@ -590,6 +610,8 @@ in brackets.
 
 =item * B<skolemize> - mint URIs instead of blank node identifiers. [0]
 
+=item * B<src_sets_object> - @src sets object URI (like @href) [0, 1]
+
 =item * B<tdb_service> - use thing-described-by.org to name some bnodes. [0]
 
 =item * B<user_agent> - a User-Agent header to use for HTTP requests. Ignored if lwp_ua is provided. [undef]
@@ -600,6 +622,8 @@ in brackets.
 
 =item * B<vocab_default> - default vocab URI (e.g. rel="foo"). [undef]
 
+=item * B<vocab_triple> - generate triple from @vocab. [0, 1]
+
 =item * B<xhtml_base> - process <base> element. 0=no, 1=yes, 2=use it for RDF/XML too. [1]                      
 
 =item * B<xhtml_elements> - process <head> and <body> specially. [1]
@@ -612,10 +636,15 @@ in brackets.
 
 =item * B<xmllit_default> - Generate XMLLiterals enthusiastically. [1, 0]
 
+=item * B<xmllit_recurse> - Look for RDFa inside XMLLiterals. [0, 1]
+
 =item * B<xmlns_attr> - Support for 'xmlns:foo' to define CURIE prefixes. [1]
 
 =back
 
+An alternative constructor C<tagsoup> is provided with a useful set of
+options for dealing with content "from the wild".
+
 =head1 EXAMPLES
 
 The following full example parses RDFa 1.1 in an Atom document, also using
@@ -638,6 +667,15 @@ any RDF/XML chunks that are embedded in the document.
   use RDF::RDFa::Parser::Config qw(HOST_XHTML RDFA_11);
   $config = RDF::RDFa::Parser::Config->new(
     HOST_XHTML, RDFA_11, embedded_rdfxml=>1);
+  $parser = RDF::RDFa::Parser->new_from_url($url, $config);
+  $data   = $parser->graph;
+
+The following config is good for dealing with (X)HTML content from the
+wild:
+
+  $config = RDF::RDFa::Parser::Config->tagsoup;
+  $parser = RDF::RDFa::Parser->new_from_url($url, $config);
+  $data   = $parser->graph;
 
 =head1 SEE ALSO
 
@@ -649,7 +687,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2008-2010 Toby Inkster
+Copyright 2008-2011 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
