@@ -4,7 +4,7 @@ use base qw(RDF::RDFa::Parser::Profile::AbstractLinkTypes);
 use common::sense;
 use 5.008;
 
-our $VERSION = '1.093';
+our $VERSION = '1.095';
 
 sub DATA
 {
@@ -21,11 +21,11 @@ DATA
 
 =head1 NAME
 
-RDF::RDFa::Parser::Profile::GRDDLLInkTypes - GRDDL Link Types
+RDF::RDFa::Parser::Profile::GRDDLLinkTypes - GRDDL Link Types
 
 =head1 DESCRIPTION
 
-Hard-coded profile for http://www.w3.org/2003/g/data-view.
+URI: http://www.w3.org/2003/g/data-view.
 
 =head1 SEE ALSO
 
@@ -38,7 +38,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2008-2010 Toby Inkster
+Copyright 2008-2011 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
