@@ -4,7 +4,7 @@ use base qw(RDF::RDFa::Parser::Profile::AbstractLinkTypes);
 use common::sense;
 use 5.008;
 
-our $VERSION = '1.094';
+our $VERSION = '1.095';
 
 sub DATA
 {
@@ -29,11 +29,11 @@ DATA
 
 =head1 NAME
 
-RDF::RDFa::Parser::Profile::HTML32LinkTypes
+RDF::RDFa::Parser::Profile::HTML32LinkTypes - HTML 3.2 Link Types
 
 =head1 DESCRIPTION
 
-Hard-coded profile for HTML 3.2 Link Types.
+HTML 3.2 Link Types.
 
 =head1 SEE ALSO
 
